unit devicecap;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs;

type
  TDeviceCap = class(TComponent)
  private
    FDisplayDriver         :string;
    FDriverType            :string;
    FScreenSizeH           :string;
    FScreenSizeV           :string;
    FScreenResolutionH     :string;
    FScreenResolutionV     :string;
    FPixelspInchH          :string;
    FPixelspInchV          :string;
    FBitspPixel            :string;
    FPixelWidth            :string;
    FPixelHeight           :string;
    FPixelDiagonal         :string;
    FRasterCapabilities    :TStrings;
    FCurveCapabilities     :TStrings;
    FLineCapabilities      :TStrings;
    FPolygonalCapabilities :TStrings;
    FTextCapabilities      :TStrings;
  protected
    { Protected declarations }
  public
    constructor create(AOwner:TComponent); override;
    destructor destroy; override;
    procedure refresh(TheForm :TForm);
    property DisplayDriver         :string read FDisplayDriver;
    property DriverType            :string read FDriverType;
    property ScreenSizeH           :string read FScreenSizeH;
    property ScreenSizeV           :string read FScreenSizeV;
    property ScreenResolutionH     :string read FScreenResolutionH;
    property ScreenResolutionV     :string read FScreenResolutionV;
    property PixelspInchH          :string read FPixelspInchH;
    property PixelspInchV          :string read FPixelspInchV;
    property BitspPixel            :string read FBitspPixel;
    property PixelWidth            :string read FPixelWidth;
    property PixelHeight           :string read FPixelHeight;
    property PixelDiagonal         :string read FPixelDiagonal;
    property RasterCapabilities    :TStrings read FRasterCapabilities;
    property CurveCapabilities     :TStrings read FCurveCapabilities;
    property LineCapabilities      :TStrings read FLineCapabilities;
    property PolygonalCapabilities :TStrings read FPolygonalCapabilities;
    property TextCapabilities      :TStrings read FTextCapabilities;
  published
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('Smart', [TDeviceCap]);
end;

constructor TDeviceCap.create(AOwner:TComponent);
begin
  inherited create(AOwner);
  FRasterCapabilities:=tstringlist.create;
  FCurveCapabilities:=tstringlist.create;
  FLineCapabilities:=tstringlist.create;
  FPolygonalCapabilities:=tstringlist.create;
  FTextCapabilities:=tstringlist.create;
end;

destructor TDeviceCap.destroy;
begin
  FCurveCapabilities.Free;
  FLineCapabilities.Free;
  FPolygonalCapabilities.Free;
  FTextCapabilities.Free;
  inherited destroy;
end;

procedure TDeviceCap.refresh(TheForm :TForm);
begin
  {driver version}
  FDisplayDriver:=IntToSTr(GetDeviceCaps(TheForm.Canvas.Handle,DRIVERVERSION));

  {the technology}
  case GetDeviceCaps(TheForm.Canvas.Handle, TECHNOLOGY) of
    DT_PLOTTER:    FDriverType:='Vector Plotter';
    DT_RASDISPLAY: FDriverType:='Raster Display';
    DT_RASPRINTER: FDriverType:='Raster Printer';
    DT_RASCAMERA:  FDriverType:='Raster Camera';
    DT_CHARSTREAM: FDriverType:='Character Stream';
    DT_METAFILE:   FDriverType:='Metafile';
    DT_DISPFILE:   FDriverType:='Display File';
  end;

  {screen size}
  FScreenSizeH:=IntToStr(GetDeviceCaps(TheForm.Canvas.Handle, HORZSIZE));
  FScreenSizeV:=IntToStr(GetDeviceCaps(TheForm.Canvas.Handle, VERTSIZE));

  {screen resolution}
  FScreenResolutionH:=IntToStr(GetDeviceCaps(TheForm.Canvas.Handle, HORZRES));
  FScreenResolutionV:=IntToStr(GetDeviceCaps(TheForm.Canvas.Handle, VERTRES));

  {pixels per logical inch Horizontal}
  FPixelspInchH:=IntToStr(GetDeviceCaps(TheForm.Canvas.Handle, LOGPIXELSX));
  {pixels per logical inch Vertical}
  FPixelspInchV:=IntToStr(GetDeviceCaps(TheForm.Canvas.Handle, LOGPIXELSY));

  {bits per pixel}
  FBitspPixel:=IntToStr(GetDeviceCaps(TheForm.Canvas.Handle, BITSPIXEL));

  {pixel dimensions}
  FPixelWidth:=IntToStr(GetDeviceCaps(TheForm.Canvas.Handle, ASPECTX));
  FPixelHeight:=IntToStr(GetDeviceCaps(TheForm.Canvas.Handle, ASPECTY));
  FPixelDiagonal:=IntToStr(GetDeviceCaps(TheForm.Canvas.Handle, ASPECTXY));

  {raster capabilities}
  FRasterCapabilities.Clear;
  if (GetDeviceCaps(TheForm.Canvas.Handle, RASTERCAPS) and
      RC_BANDING)=RC_BANDING then
        FRasterCapabilities.Add('Requires Banding');
  if (GetDeviceCaps(TheForm.Canvas.Handle, RASTERCAPS) and
      RC_BITBLT)=RC_BITBLT then
        FRasterCapabilities.Add('Can Transer Bitmaps');
  if (GetDeviceCaps(TheForm.Canvas.Handle, RASTERCAPS) and
      RC_BITMAP64)=RC_BITMAP64 then
        FRasterCapabilities.Add('Supports Bitmaps > 64K');
  if (GetDeviceCaps(TheForm.Canvas.Handle, RASTERCAPS) and
      RC_DI_BITMAP)=RC_DI_BITMAP then
        FRasterCapabilities.Add('Supports SetDIBits and GetDIBits');
  if (GetDeviceCaps(TheForm.Canvas.Handle, RASTERCAPS) and
      RC_DIBTODEV)=RC_DIBTODEV then
        FRasterCapabilities.Add('Supports SetDIBitsToDevice');
  if (GetDeviceCaps(TheForm.Canvas.Handle, RASTERCAPS) and
      RC_FLOODFILL)=RC_FLOODFILL then
        FRasterCapabilities.Add('Can Perform Floodfills');
  if (GetDeviceCaps(TheForm.Canvas.Handle, RASTERCAPS) and
      RC_GDI20_OUTPUT)=RC_GDI20_OUTPUT then
        FRasterCapabilities.Add('Supports Windows 2.0 Features');
  if (GetDeviceCaps(TheForm.Canvas.Handle, RASTERCAPS) and
      RC_PALETTE)=RC_PALETTE then
        FRasterCapabilities.Add('Palette Based');
  if (GetDeviceCaps(TheForm.Canvas.Handle, RASTERCAPS) and
      RC_SCALING)=RC_SCALING then
        FRasterCapabilities.Add('Supports Scaling');
  if (GetDeviceCaps(TheForm.Canvas.Handle, RASTERCAPS) and
      RC_STRETCHBLT)=RC_STRETCHBLT then
        FRasterCapabilities.Add('Supports StretchBlt');
  if (GetDeviceCaps(TheForm.Canvas.Handle, RASTERCAPS) and
      RC_STRETCHDIB)=RC_STRETCHDIB then
        FRasterCapabilities.Add('Supports StretchDIBits');

  {curve capabilities}
  FCurveCapabilities.clear;
  if GetDeviceCaps(TheForm.Canvas.Handle, CURVECAPS)=CC_NONE then
    FCurveCapabilities.Add('Device Does Not Support Curves')
  else
  begin
    if (GetDeviceCaps(TheForm.Canvas.Handle, CURVECAPS) and
        CC_CIRCLES)=CC_CIRCLES then
          FCurveCapabilities.Add('Supports Cirles');
    if (GetDeviceCaps(TheForm.Canvas.Handle, CURVECAPS) and
        CC_PIE)=CC_PIE then
          FCurveCapabilities.Add('Supports Pie Wedges');
    if (GetDeviceCaps(TheForm.Canvas.Handle, CURVECAPS) and
        CC_CHORD)=CC_CHORD then
          FCurveCapabilities.Add('Supports Chords');
    if (GetDeviceCaps(TheForm.Canvas.Handle, CURVECAPS) and
        CC_ELLIPSES)=CC_ELLIPSES then
          FCurveCapabilities.Add('Supports Ellipses');
    if (GetDeviceCaps(TheForm.Canvas.Handle, CURVECAPS) and
        CC_WIDE)=CC_WIDE then
          FCurveCapabilities.Add('Supports Wide Borders');
    if (GetDeviceCaps(TheForm.Canvas.Handle, CURVECAPS) and
        CC_STYLED)=CC_STYLED then
          FCurveCapabilities.Add('Supports Styled Borders');
    if (GetDeviceCaps(TheForm.Canvas.Handle, CURVECAPS) and
        CC_WIDESTYLED)=CC_WIDESTYLED then
          FCurveCapabilities.Add('Supports Wide And Styled Borders');
    if (GetDeviceCaps(TheForm.Canvas.Handle, CURVECAPS) and
        CC_INTERIORS)=CC_INTERIORS then
          FCurveCapabilities.Add('Supports Interiors');
    if (GetDeviceCaps(TheForm.Canvas.Handle, CURVECAPS) and
        CC_ROUNDRECT)=CC_ROUNDRECT then
          FCurveCapabilities.Add('Supports Rounded Rectangles');
  end;

  {line capabilities}
  FLineCapabilities.clear;
  if GetDeviceCaps(TheForm.Canvas.Handle, LINECAPS)=LC_NONE then
    FLineCapabilities.Add('Device Does Not Support Lines')
  else
  begin
    if (GetDeviceCaps(TheForm.Canvas.Handle, LINECAPS) and
        LC_POLYLINE)=LC_POLYLINE then
          FLineCapabilities.Add('Supports Polylines');
    if (GetDeviceCaps(TheForm.Canvas.Handle, LINECAPS) and
        LC_MARKER)=LC_MARKER then
          FLineCapabilities.Add('Supports Markers');
    if (GetDeviceCaps(TheForm.Canvas.Handle, LINECAPS) and
        LC_POLYMARKER)=LC_POLYMARKER then
          FLineCapabilities.Add('Supports Multiple Markers');
    if (GetDeviceCaps(TheForm.Canvas.Handle, LINECAPS) and
        LC_WIDE)=LC_WIDE then
          FLineCapabilities.Add('Supports Wide Lines');
    if (GetDeviceCaps(TheForm.Canvas.Handle, LINECAPS) and
        LC_STYLED)=LC_STYLED then
          FLineCapabilities.Add('Supports Styled Lines');
    if (GetDeviceCaps(TheForm.Canvas.Handle, LINECAPS) and
        LC_WIDESTYLED)=LC_WIDESTYLED then
          FLineCapabilities.Add('Supports Wide And Styled Lines');
    if (GetDeviceCaps(TheForm.Canvas.Handle, LINECAPS) and
        LC_INTERIORS)=LC_INTERIORS then
          FLineCapabilities.Add('Supports Interiors');
  end;

  {polygonal capabilities}
  FPolygonalCapabilities.clear;
  if GetDeviceCaps(TheForm.Canvas.Handle, POLYGONALCAPS)=PC_NONE then
    FPolygonalCapabilities.Add('Device Does Not Support Polygons')
  else
  begin
    if (GetDeviceCaps(TheForm.Canvas.Handle, POLYGONALCAPS) and
        PC_POLYGON)=PC_POLYGON then
          FPolygonalCapabilities.Add('Supports Alternate Fill Polygons');
    if (GetDeviceCaps(TheForm.Canvas.Handle, POLYGONALCAPS) and
        PC_RECTANGLE)=PC_RECTANGLE then
          FPolygonalCapabilities.Add('Supports Rectangles');
    if (GetDeviceCaps(TheForm.Canvas.Handle, POLYGONALCAPS) and
        PC_WINDPOLYGON)=PC_WINDPOLYGON then
          FPolygonalCapabilities.Add('Supports Winding Fill Polygons');
    if (GetDeviceCaps(TheForm.Canvas.Handle, POLYGONALCAPS) and
        PC_SCANLINE)=PC_SCANLINE then
          FPolygonalCapabilities.Add('Supports Single Scanlines');
    if (GetDeviceCaps(TheForm.Canvas.Handle, POLYGONALCAPS) and
        PC_WIDE)=PC_WIDE then
          FPolygonalCapabilities.Add('Supports Wide Borders');
    if (GetDeviceCaps(TheForm.Canvas.Handle, POLYGONALCAPS) and
        PC_STYLED)=PC_STYLED then
          FPolygonalCapabilities.Add('Supports Styled Borders');
    if (GetDeviceCaps(TheForm.Canvas.Handle, POLYGONALCAPS) and
        PC_WIDESTYLED)=PC_WIDESTYLED then
          FPolygonalCapabilities.Add('Supports Wide And Styled Borders');
    if (GetDeviceCaps(TheForm.Canvas.Handle, POLYGONALCAPS) and
        PC_INTERIORS)=PC_INTERIORS then
          FPolygonalCapabilities.Add('Supports Interiors');
  end;

  {text capabilities}
  FTextCapabilities.clear;
  if (GetDeviceCaps(TheForm.Canvas.Handle, TEXTCAPS) and
      TC_OP_CHARACTER)=TC_OP_CHARACTER then
        FTextCapabilities.Add('Capable of Character Output Precision');
  if (GetDeviceCaps(TheForm.Canvas.Handle, TEXTCAPS) and
      TC_OP_STROKE)=TC_OP_STROKE then
        FTextCapabilities.Add('Capable of Stroke Output Precision');
  if (GetDeviceCaps(TheForm.Canvas.Handle, TEXTCAPS) and
      TC_CP_STROKE)=TC_CP_STROKE then
        FTextCapabilities.Add('Capable of Stroke Clip Precision');
  if (GetDeviceCaps(TheForm.Canvas.Handle, TEXTCAPS) and
      TC_CR_90)=TC_CR_90 then
        FTextCapabilities.Add('Supports 90 Degree Character Rotation');
  if (GetDeviceCaps(TheForm.Canvas.Handle, TEXTCAPS) and
      TC_CR_ANY)=TC_CR_ANY then
        FTextCapabilities.Add('Supports Character Rotation to Any Angle');
  if (GetDeviceCaps(TheForm.Canvas.Handle, TEXTCAPS) and
      TC_SF_X_YINDEP)=TC_SF_X_YINDEP then
        FTextCapabilities.Add('X And Y Scale Independent');
  if (GetDeviceCaps(TheForm.Canvas.Handle, TEXTCAPS) and
      TC_SA_DOUBLE)=TC_SA_DOUBLE then
        FTextCapabilities.Add('Supports Doubled Character Scaling');
  if (GetDeviceCaps(TheForm.Canvas.Handle, TEXTCAPS) and
      TC_SA_INTEGER)=TC_SA_INTEGER then
        FTextCapabilities.Add('Supports Integer Multiples Only When Scaling');
  if (GetDeviceCaps(TheForm.Canvas.Handle, TEXTCAPS) and
      TC_SA_CONTIN)=TC_SA_CONTIN then
        FTextCapabilities.Add('Supports Any Multiples For Exact Character Scaling');
  if (GetDeviceCaps(TheForm.Canvas.Handle, TEXTCAPS) and
      TC_EA_DOUBLE)=TC_EA_DOUBLE then
        FTextCapabilities.Add('Supports Double Weight Characters');
  if (GetDeviceCaps(TheForm.Canvas.Handle, TEXTCAPS) and
      TC_IA_ABLE)=TC_IA_ABLE then
        FTextCapabilities.Add('Supports Italics');
  if (GetDeviceCaps(TheForm.Canvas.Handle, TEXTCAPS) and
      TC_UA_ABLE)=TC_UA_ABLE then
        FTextCapabilities.Add('Supports Underlines');
  if (GetDeviceCaps(TheForm.Canvas.Handle, TEXTCAPS) and
      TC_SO_ABLE)=TC_SO_ABLE then
        FTextCapabilities.Add('Supports Strikeouts');
  if (GetDeviceCaps(TheForm.Canvas.Handle, TEXTCAPS) and
      TC_RA_ABLE)=TC_RA_ABLE then
        FTextCapabilities.Add('Supports Raster Fonts');
  if (GetDeviceCaps(TheForm.Canvas.Handle, TEXTCAPS) and
      TC_VA_ABLE)=TC_VA_ABLE then
        FTextCapabilities.Add('Supports Vector Fonts');
  if (GetDeviceCaps(TheForm.Canvas.Handle, TEXTCAPS) and
      TC_SCROLLBLT)=TC_SCROLLBLT then
        FTextCapabilities.Add('Cannot Scroll Using Blts');

end;


end.
